Include "names.par"

Group {

boundaryregionline = #BOUNDARY_REGIONLINE;
//2d
conductorsurface1= #CONDUCTORSURFACE_1;
conductorsurface2= #CONDUCTORSURFACE_2;

boundaryregionsurface = #BOUNDARY_REGIONSURFACE;

Vol = #{boundaryregionsurface,conductorsurface1,conductorsurface2};
Source = #{conductorsurface1,conductorsurface2};
}

Function {
mu0=4.e-7*Pi;  //Permeability
nu[Vol]=1/mu0; //InversePermeability
itot=100;       //Current

//conductor plate area is length*height - cross sectional
area=100*10;
j[conductorsurface1]=Vector[0,0,itot/area];
j[conductorsurface2]=Vector[0,0,itot/area];
}
Jacobian {
  { Name Vol ; Case {
    // All domains expand in to infinity in z direction
      { Region All ; Jacobian Vol ; }
  } }
}

Integration {
  { Name Int ; Case { { Type Gauss ;
  Case {
    // 3D elements are not relevant
    // This block defines the accuracy for the numerical integrations
    // Higher NumberOfPoint should correspond to higher accuracy in case
    // of nonlinear behaviour within single cells.
    { GeoElement Point       ; NumberOfPoints  1 ; }
    { GeoElement Line        ; NumberOfPoints  3 ; }
    { GeoElement Triangle    ; NumberOfPoints  4 ; }
    { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
    { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
    { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
    { GeoElement Pyramid     ; NumberOfPoints  8 ; }
    { GeoElement Prism       ; NumberOfPoints  6 ; }
    }
  } } }
}

Constraint {
  { Name a ;
    Case {
      //boundary condition for a
      { Region boundaryregionline ; Value 0. ; }
    }
  }
}

FunctionSpace {

  { Name Hcurl_a ; Type Form1P ;
    BasisFunction {
      //only in z direction
      { Name se ; NameOfCoef ae ; Function BF_PerpendicularEdge ;
        Support Vol ; Entity NodesOf[ All ] ; }
    }
    Constraint {
      { NameOfCoef ae ; EntityType NodesOf ; NameOfConstraint a ; }
    }
  }

}

Formulation {
  { Name MagSta_a ; Type FemEquation ;
    Quantity {
      { Name a  ; Type Local ; NameOfSpace Hcurl_a ; }
    }
    Equation {
      // rot(1/mu rot A) =0 usually
      Galerkin { [ nu[] * Dof{d a} , {d a} ] ;
                In Vol ; Jacobian Vol ; Integration Int ; }

      //addinonal right hand side term for a:
      // +=j
      Galerkin { [ j[] , { a} ] ;
                In Source; Jacobian Vol ; Integration Int ; }
    }
  }
}

Resolution
{
  {  Name all;System
    {
        { Name A1 ; NameOfFormulation MagSta_a;}
    }
    Operation
    {
      Generate[A1] ;
      Solve[A1] ;
      SaveSolution[A1] ;

    }
  }
}

PostProcessing {
  { Name all ; NameOfFormulation MagSta_a;  Quantity
  {
    { Name b ; Value { Local { [ {d a} ] ; In Vol ; Jacobian Vol; } } }
    { Name nb ; Value { Local { [ Norm[{d a}] ] ; In Vol ; Jacobian Vol; } } }
    { Name ene ; Value { Local { [ 1/mu0*Norm[{d a}]*Norm[{d a}] ] ; In Vol ; Jacobian Vol; } } }

    { Name L ; Value { Integral{ [ 1/mu0*Norm[{d a}]*Norm[{d a}] ] ; In Vol ; Jacobian Vol; Integration Int;} } }

    { Name j ; Value {
      Local { [ j[] ] ; In Source; Jacobian Vol; }
      Local { [ 0 ] ; In boundaryregionsurface; Jacobian Vol; }
    } }
  }
  }
}


PostOperation{
  { Name all ; NameOfPostProcessing all;
    Operation {
      Print[ b , OnElementsOf Vol , File "b.pos" ] ;

      //norm b
      Print[ nb , OnElementsOf Vol , File "nb.pos" ] ;

      //field energy
      Print[ ene , OnElementsOf Vol , File "ene.pos" ] ;

      //current
      Print[ j , OnElementsOf Vol , File "j.pos" ] ;

      //simulated L
      Print[ L[Vol], OnGlobal, Format Table,File "output.txt" ] ;
      Print[ L[Vol], OnGlobal, Format Table ] ;
    }
  }

  { Name short ; NameOfPostProcessing all;
    Operation {
        Print[ L[Vol], OnGlobal, Format Table,File "output.txt" ] ;
        Print[ L[Vol], OnGlobal, Format Table] ;
    }
  }
}
